nx.graphic.Topology.TooltipManager - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.TooltipManager Class

Extends nx.data.ObservableObject
Module: nx.graphic.Topology

Tooltip manager for topology

- Index
- Methods
- Properties

## Item Index

### Methods

- clearBinding
- closeAll
- dispose
- get
- getBinding
- gets
- has
- linkSetTooltip
- notify
- openLinkSetTooltip
- openLinkTooltip
- openNodeSetTooltip
- openNodeTooltip
- set
- setBinding
- unwatch

### Properties

- activated
- linkSetTooltipClass
- linkSetTooltipContentClass
- linkTooltip
- linkTooltipClass
- linkTooltipContentClass
- nodeTooltip
- nodeTooltipClass
- nodeTooltipContentClass
- showLinkSetTooltip
- showLinkTooltip
- showNodeTooltip
- tooltipPolicyClass
- topology

## Methods

### `clearBinding`

(

- `prop`

)

Inherited from nx.Observable:

Clear binding for specified property.

#### Parameters:

- `prop` Object

### `closeAll`

()

Close all tooltip

### `dispose`

()

Inherited from nx.Observable

Dispose current object.

### `get`

(

- `name`

)

Inherited from nx.data.ObservableObject:

Get specified property value.

#### Parameters:

- `name` String

#### Returns:

:

### ``

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

### `getBinding`

(

- `prop`

)

Inherited from nx.Observable:

Get existing binding object for specified property.

#### Parameters:

- `prop` Object

#### Returns:

:

### `gets`

() Object

Inherited from nx.data.ObservableObject:

Get all properties.

#### Returns:

Object:

### `has`

(

- `name`

)
Boolean

Inherited from nx.data.ObservableObject:

Check whether current object has specified property.

#### Parameters:

- `name` String

#### Returns:

Boolean:

### `linkSetTooltip`

()

Get linkSet tooltip

### `notify`

(

- `names`
- `oldValue`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `oldValue` Object

### `openLinkSetTooltip`

(

- `linkSet`
- `position`

)

Open linkSet tooltip

#### Parameters:

- `linkSet` Object
- `position` Object

### `openLinkTooltip`

(

- `link`
- `position`

)

open a link's tooltip

#### Parameters:

- `link` Object
- `position` Object

### `openNodeSetTooltip`

(

- `nodeSet`
- `position`

)

Open a nodeSet's tooltip

#### Parameters:

- `nodeSet` nx.graphic.Topology.NodeSet
- `position` Object

### `openNodeTooltip`

(

- `node`
- `position`

)

Open a node's tooltip

#### Parameters:

- `node` nx.graphic.Topology.Node
- `position` Object

### `set`

(

- `name`
- `value`

)

Inherited from nx.data.ObservableObject:

Set specified property value.

#### Parameters:

- `name` String
- `value`

### `setBinding`

(

- `prop`
- `expr`
- `source`

)

Inherited from nx.Observable:

Set binding for specified property.

#### Parameters:

- `prop` Object
- `expr` Object
- `source` Object

### `unwatch`

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

## Properties

### `activated`

Unknown

Set/get tooltip's activate statues

### `linkSetTooltipClass`

Unknown

linkSet tooltip class

### `linkSetTooltipContentClass`

Unknown

### `linkTooltip`

Unknown

Get link's tooltip

### `linkTooltipClass`

Unknown

link tooltip class

### `linkTooltipContentClass`

Unknown

### `nodeTooltip`

Unknown

Get node's tooltip

### `nodeTooltipClass`

Unknown

node tooltip class

### `nodeTooltipContentClass`

Unknown

### `showLinkSetTooltip`

Boolean

Show/hide linkSet's tooltip

### `showLinkTooltip`

Boolean

Show/hide link's tooltip

### `showNodeTooltip`

Boolean

Show/hide node's tooltip

### `tooltipPolicyClass`

Unknown

Tooltip policy class

### `topology`

Unknown

Get topology